import ssl
import hashlib
import textwrap
import configparser
import os
import getpass

hostname = "repo.rt247a.ddns.me"
port = 443

def opt_create_section(config, sec):
    if not sec in config:
        config.add_section(sec)

def opt_create_key(config, sec, key):
    if not key in config[sec]:
        config[sec][key] = ''

conn = ssl.create_connection((hostname, port))
context = ssl.SSLContext(ssl.PROTOCOL_SSLv23)
sock = context.wrap_socket(conn, server_hostname=hostname)

der_cert_bin = sock.getpeercert(True)
thumb_sha256 = hashlib.sha256(der_cert_bin).hexdigest()
chunks = textwrap.wrap(thumb_sha256, 2)
sha256 = ':'.join(chunks)

config = configparser.ConfigParser(delimiters='=')
config.read(os.path.expanduser('~/mercurial.ini'))

opt_create_section(config, 'ui')
opt_create_section(config, 'extensions')
opt_create_section(config, 'auth')
opt_create_section(config, 'hostsecurity')

if not 'username' in config['ui']:
    name = input('Input your full name [John Smith]: ')
    email = input('Input your email: ')
    config['ui']['username'] = name + " <" + email + ">"

if not hostname + '.prefix' in config['auth']:
    login = input('Input your repository login: ')
    password = getpass.getpass('Input your repository password: ')
    config['auth'][hostname + '.prefix'] = 'https://' + hostname
    config['auth'][hostname + '.username'] = login
    config['auth'][hostname + '.password'] = password

config['hostsecurity'][hostname + ':fingerprints'] = 'sha256:' + sha256

opt_create_key(config, 'extensions', 'fetch')
opt_create_key(config, 'extensions', 'largefiles')
opt_create_key(config, 'extensions', 'progress')

with open(os.path.expanduser('~\\mercurial.ini'), 'w') as configfile:
    config.write(configfile)

print('Mercurial settings file updated.')
print('Check changes in ' + os.path.expanduser('~\\mercurial.ini'))